@@ -12,7 +12,7 @@ args = list(
   refFile      = file.path(datapath, 'hammer-reference.csv'),
   nUnknowns    = 1,
   doDropin     = TRUE,
-  ethnic       = "EA1",
+  ethnic       = "NDU1",
   adj          = 1.0,
   fst          = 0.02,
   relatedness  = c(0, 0)/4
